Gene annotation information: version 2 - january 2022 - suited for alias conversion
Source:R/data.R
geneinfo_alias_human.RdA data.frame/tibble describing HGNC human gene symbols, their entrez ids and potential aliases.
R/data.R
geneinfo_alias_human.RdA data.frame/tibble describing HGNC human gene symbols, their entrez ids and potential aliases.