Gene annotation information: version 2 - january 2022 - suited for alias conversion
Source:R/data.R
geneinfo_alias_mouse.RdA data.frame/tibble describing MGI mouse gene symbols, their entrez ids and potential aliases.
R/data.R
geneinfo_alias_mouse.RdA data.frame/tibble describing MGI mouse gene symbols, their entrez ids and potential aliases.