get_muscat_exprs_avg Calculate sample- and group-average of gene expression per cell type.
Arguments
- sce
SingleCellExperiment object of the scRNAseq data of interest. Contains both sender and receiver cell types.
- sample_id
Name of the meta data column that indicates from which sample/patient a cell comes from
- celltype_id
Name of the column in the meta data of sce that indicates the cell type of a cell.
- group_id
Name of the meta data column that indicates from which group/condition a cell comes from