get_pseudobulk_logCPM_exprs Calculate the 'library-size' normalized pseudbulk counts per sample for each gene - returned values are similar to logCPM.
Usage
get_pseudobulk_logCPM_exprs(sce, sample_id, celltype_id, group_id, batches = NA, assay_oi_pb = "counts", fun_oi_pb = "sum")Arguments
- sce
SingleCellExperiment object of the scRNAseq data of interest. Contains both sender and receiver cell types.
- sample_id
Name of the meta data column that indicates from which sample/patient a cell comes from
- celltype_id
Name of the column in the meta data of sce that indicates the cell type of a cell.
- group_id
Name of the meta data column that indicates from which group/condition a cell comes from
- batches
NA if no batches should be corrected for. If there should be corrected for batches during DE analysis and pseudobulk expression calculation, this argument should be the name(s) of the columns in the meta data that indicate the batch(s). Should be categorical. Pseudobulk expression values will be corrected for the first element of this vector.
- assay_oi_pb
Indicates which information of the assay of interest should be used (counts, scaled data,...). Default: "counts". See `muscat::aggregateData`.
- fun_oi_pb
Indicates way of doing the pseudobulking. Default: "sum". See `muscat::aggregateData`.