prioritize_condition_specific_sender
Source:R/condition_specific_celltypes.R
prioritize_condition_specific_sender.Rdprioritize_condition_specific_sender Perform the MultiNicheNet prioritization of cell-cell interactions. Focus on including condition-specific cell types as sender cells. This implies no DE information will be used for prioritization of ligands.
Usage
prioritize_condition_specific_sender(abundance_info, abundance_expression_info, condition_specific_celltypes, grouping_tbl, fraction_cutoff, contrast_tbl, sender_receiver_de, lr_network, ligand_activities_targets_DEgenes, scenario = "regular", ligand_activity_down = FALSE)Arguments
- abundance_info
Output from `make_abundance_plots`
- abundance_expression_info
Output from `get_abundance_expression_info`
- condition_specific_celltypes
Character vector of condition-specific cell types
- grouping_tbl
Data frame showing the groups of each sample (and batches per sample if applicable) (columns: sample and group; and if applicable all batches of interest)
- fraction_cutoff
Cutoff indicating the minimum fraction of cells of a cell type in a specific sample that are necessary to consider a gene (e.g. ligand/receptor) as expressed in a sample.
- contrast_tbl
Data frame providing names for each of the contrasts in contrasts_oi in the 'contrast' column, and the corresponding group of interest in the 'group' column. Entries in the 'group' column should thus be present in the group_id column in the metadata. Example for `contrasts_oi = c("'A-(B+C+D)/3', 'B-(A+C+D)/3'")`: `contrast_tbl = tibble(contrast = c("A-(B+C+D)/3","B-(A+C+D)/3"), group = c("A","B"))`
- sender_receiver_de
Output of `combine_sender_receiver_de`
- lr_network
Prior knowledge Ligand-Receptor network (columns: ligand, receptor)
- ligand_activities_targets_DEgenes
Output of `get_ligand_activities_targets_DEgenes`
- scenario
Character vector indicating which prioritization weights should be used during the MultiNicheNet analysis. Currently 3 settings are implemented: "regular" (default), "lower_DE", and "no_frac_LR_expr". The setting "regular" is strongly recommended and gives each criterion equal weight. The setting "lower_DE" is recommended in cases your hypothesis is that the differential CCC patterns in your data are less likely to be driven by DE (eg in cases of differential migration into a niche). It halves the weight for DE criteria, and doubles the weight for ligand activity. "no_frac_LR_expr" is the scenario that will exclude the criterion "fraction of samples expressing the LR pair'. This may be beneficial in case of few samples per group.
- ligand_activity_down
For prioritization based on ligand activity: consider the max of up- and downregulation (`TRUE`) or consider only upregulated activity (`FALSE`, default from version 2 on).